# CV-pose

CV-pose is a light Python library using and testing a number of pose estimation networks. Built on Tensorflow.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip3 install cv-pose
```

## License

[MIT](https://choosealicense.com/licenses/mit/)